"""The product type for sites. Used for tying together shared information between the products that reside here."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.site import (
    SiteBlock,
    SiteBlockInactive,
    SiteBlockProvisioning,
)


class SiteInactive(SubscriptionModel, is_base=True):
    """A site that is inactive."""

    site: SiteBlockInactive


class SiteProvisioning(SiteInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A site that is being provisioned."""

    site: SiteBlockProvisioning


class Site(SiteProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """A site that is currently active."""

    site: SiteBlock


class ImportedSiteInactive(SubscriptionModel, is_base=True):
    """An imported site that is inactive."""

    site: SiteBlockInactive


class ImportedSite(ImportedSiteInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]):
    """An imported site that is currently active."""

    site: SiteBlock
